package com.chinaitop.depot.intelligent.basicdata.controller;

import com.chinaitop.depot.intelligent.basicdata.model.TStation;
import com.chinaitop.depot.intelligent.basicdata.service.StationService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unissoft.model.ResponseEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value = "/intelligents/station")
@Api(value = "StationController", description = "通信设备控制类")
public class StationController {

    @Resource
    private StationService stationService;

    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "查询 通信设备 信息列表", notes = "查询 通信设备 信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "zdname", value = "站点名称", paramType = "query")
    })
    public ResponseEntity<PageInfo<TStation>> getList(Integer pageNum, Integer pageSize, String vZdName) {
        List<TStation> list = null;
        try {
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = stationService.getList(vZdName);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询通信列表失败");
        }
        PageInfo<TStation> pageInfo = new PageInfo<TStation>(list);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/getById", method = RequestMethod.POST)
    @ApiOperation(value = "根据通信id查询 信息", notes = "根据通信id查询 信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "通信id", paramType = "query")
    })
    public ResponseEntity<TStation> getById(String id) {
        TStation tLqinfo = null;
        if (StringUtils.isNotBlank(id)) {
            tLqinfo = stationService.getById(id);
        } else {
            return ResponseEntity.failed("ID数据有误!");
        }
        return ResponseEntity.ok(tLqinfo);
    }

    @RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据更新与添加", notes = "数据更新与添加")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "grainJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity save(String grainJson) {
        try {
            stationService.save(grainJson);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("更新失败");
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.POST)
    @ApiOperation(value = "根据通信id删除", notes = "根据通信id删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "通信id", paramType = "query"),
            @ApiImplicitParam(name = "stationJson", value = "通信设置信息", paramType = "form")
    })
    public ResponseEntity deleteById(String id, String stationJson) {
        if (StringUtils.isNotBlank(id)) {
            int count = stationService.deleteById(id, stationJson);
            if (count > 0) {
                return ResponseEntity.ok();
            } else {
                return ResponseEntity.failed("删除失败!");
            }
        }
        return ResponseEntity.failed("ID数据有误!");
    }

    @RequestMapping(value = "/getStations", method = RequestMethod.GET)
    @ApiOperation(value = "查询 通信设备 信息列表", notes = "查询 通信设备 信息列表")
    public ResponseEntity getStations() {
        Map<String, TStation> stations = stationService.getStations();
        return ResponseEntity.ok(stations);
    }

    @RequestMapping(value = "/getBycfCode", method = RequestMethod.GET)
    @ApiOperation(value = "校验是否重复 通信设备", notes = "校验是否重复 通信设备")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vdevcode", value = "设备编码", paramType = "query"),
            @ApiImplicitParam(name = "vdevname", value = "设备名称", paramType = "query")
    })
    public ResponseEntity getBycfCode(String vdevcode, String vdevname) {
        boolean bycfCode = stationService.getBycfCode(vdevcode, vdevname);
        return ResponseEntity.ok(bycfCode);
    }


    @RequestMapping(value = "/synchronizationAll", method = RequestMethod.GET)
    @ApiOperation(value = "与智远同步通信设置基础数据", notes = "与智远同步通信设置基础数据")
    @ApiImplicitParam(name = "orgId", value = "库房编码", paramType = "query")
    public ResponseEntity synchronizationAll(String orgId) {
        if (StringUtils.isBlank(orgId)){
            return ResponseEntity.ok("库房编码不能为空！");
        }
        String msg = null;
        try {
            msg = stationService.synchronizationAll(orgId);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.ok("同步失败！");
        }
        return ResponseEntity.ok(msg);
    }
}
